/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Michael Hashimoto
 */
public class JobFactory {

	public static PortalRepositoryJob newPortalRepositoryJob(String jobName) {
		return newPortalRepositoryJob(jobName, "default");
	}

	public static PortalRepositoryJob newPortalRepositoryJob(
		String jobName, String testSuiteName) {

		if (_jobs.containsKey(jobName)) {
			Job job = _jobs.get(jobName);

			if (job instanceof PortalRepositoryJob) {
				return (PortalRepositoryJob)_jobs.get(jobName);
			}

			throw new RuntimeException(
				jobName + " is not a portal repository job");
		}

		PortalRepositoryJob portalRepositoryJob = null;

		if (jobName.contains("test-portal-acceptance-pullrequest(")) {
			portalRepositoryJob = new PortalAcceptancePullRequestJob(
				jobName, testSuiteName);
		}
		else if (jobName.contains("test-portal-acceptance-upstream(")) {
			portalRepositoryJob = new PortalAcceptanceUpstreamJob(jobName);
		}
		else {
			throw new RuntimeException("Invalid job name " + jobName);
		}

		if (portalRepositoryJob != null) {
			_jobs.put(jobName, portalRepositoryJob);
		}

		return portalRepositoryJob;
	}

	private static final Map<String, Job> _jobs = new HashMap<>();

}