/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.util.HashMap;
import java.util.Map;

import org.json.JSONObject;

/**
 * @author Michael Hashimoto
 */
public class LabelFactory {

	public static Label newLabel(String labelsURL, String name) {
		return newLabel(labelsURL, name, null);
	}

	public static Label newLabel(String labelsURL, String name, String color) {
		if (!Label.isValidLabelsURL(labelsURL)) {
			throw new IllegalArgumentException(
				"Invalid labels URL " + labelsURL);
		}

		if (name == null) {
			throw new IllegalArgumentException("Invalid name " + name);
		}

		if (_labels.containsKey(name)) {
			Label label = _labels.get(name);

			if (color != null) {
				label.setColor(color);
			}

			return label;
		}

		Label label = new Label(labelsURL, name, color);

		_labels.put(name, label);

		return label;
	}

	protected static Label newLabel(JSONObject jsonObject) {
		String name = jsonObject.getString("name");

		if (_labels.containsKey(name)) {
			return _labels.get(name);
		}

		Label label = new Label(jsonObject);

		_labels.put(name, label);

		return label;
	}

	private static final Map<String, Label> _labels = new HashMap<>();

}